Count the number of leaf nodes in a nested list.
See also
Other lstrrr_core:
list_delete(),
list_depth(),
list_get(),
list_has(),
list_path(),
list_set()
Count the number of leaf nodes in a nested list.
Other lstrrr_core:
list_delete(),
list_depth(),
list_get(),
list_has(),
list_path(),
list_set()