Skip to contents

Applies .f to corresponding leaves of multiple nested lists for side effects.

Usage

list_pwalk(.l, .f, ..., .progress = FALSE)

Arguments

.l

A list of nested lists.

.f

A function, formula, or function-like object coercible by rlang::as_function(). Additional arguments supplied through ... are passed on to .f.

...

Additional arguments passed to .f.

.progress

Whether to show a progress

Use TRUE to turn on a basic progress, use a string to give it a name, or use a list to customize the progress bar (see ?cli::cli_progress_bar and https://cli.r-lib.org/articles/progress-advanced.html#cli_progress_bar for details).

Value

Invisibly returns .l.