Traverse a nested list and return all paths whose element is identical
to value.
See also
Other lstrrr_core:
list_delete(),
list_depth(),
list_get(),
list_has(),
list_nleaf(),
list_path(),
list_set()
Traverse a nested list and return all paths whose element is identical
to value.
Other lstrrr_core:
list_delete(),
list_depth(),
list_get(),
list_has(),
list_nleaf(),
list_path(),
list_set()