Applies .f to corresponding leaves of multiple nested lists
for side effects.
Arguments
- .l
A list of nested lists.
- .f
A function, formula, or function-like object coercible by
rlang::as_function(). Additional arguments supplied through...are passed on to.f.- ...
Additional arguments passed to
.f.- .progress
Whether to show a progress
Use TRUE to turn on a basic progress, use a string to give it a name, or use a list to customize the progress bar (see
?cli::cli_progress_barand https://cli.r-lib.org/articles/progress-advanced.html#cli_progress_bar for details).
See also
Other lstrrr-purrrlike:
list_flatten(),
list_imap(),
list_iwalk(),
list_map(),
list_map2(),
list_modify_if(),
list_pmap(),
list_walk(),
list_walk2()